from schemafy import make_schema

def test_make_schema():
    schema = 'a'
    assert schema == 'a'
    # make_schema("StructType(List(StructField(hvfhs_license_num,StringType,true),StructField(dispatching_base_num,StringType,true),StructField(pickup_datetime,StringType,true),StructField(dropoff_datetime,StringType,true),StructField(PULocationID,LongType,true),StructField(DOLocationID,LongType,true),StructField(SR_Flag,DoubleType,true)))")
    # assert schema == '''types.StructType([
    # types.StructField ("hvfhs_license_num",types.StringType(),True),
    # types.StructField ("dispatching_base_num",types.StringType(),True),
    # types.StructField ("pickup_datetime",types.TimestampType(),True),
    # types.StructField ("dropoff_datetime",types.TimestampType(),True),
    # types.StructField ("PULocationID",types.LongType(),True),
    # types.StructField ("DOLocationID",types.LongType(),True),
    # types.StructField ("SR_Flag",types.DoubleType(),True)])'''


from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="SparkSchemafy",
    version="0.1.1",
    description="Formats spark schema output into a schema definition",
    py_modules=["SparkSchemafy"],
    package_dir={'':'src'},
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires = ["pyspark >= 3.0.0 ",
                        "pandas >= 1.2.0"],
    extras_require = {
        "dev": [
            "pytest>=3.7",
        ],
    },
    url="https://github.com/MichaelShoemaker/schemafy",
    author="Michael Shoemaker",
    author_email="mikeshoemaker2000@yahoo.com",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"]
)


import re
import sys
from pyspark.sql import types

def make_spark_schema(raw):
    if not isinstance(raw, str):
        print('USAGE: make_spark_schema(sting)')
        print('Example: make_spark_schema(str(spark.sql.DataFram(<Pandas DataFrame>).schema))')
        sys.exit(1)

    fields = []
    
    for i in zip([i.start() for i in re.finditer("\(",raw)][2:],[i.start() for i in re.finditer("\)",raw)][:-2]):
        fields.append(raw[i[0]+1:i[1]])

    schema = "types.StructType[\n"

    ending = '\n'
    commas = len(fields) -1
    
    for f in fields:
        n = f.split(",")
        schema = schema+"\ttypes.StructField(\""+n[0]+"\", types."+n[1]+"(), "+n[2].capitalize()+")"
        if commas > 0:
            schema = schema + ',' + ending
            commas -= 1
    schema = schema + ending
    schema = schema +"])"
    print(schema)

def make_delta_schema(file, table_name='your_table', db = 'default', delta_loc='./delta'):
    print("spark.sql('''")
    print(f"CREATE TABLE IF NOT EXISTS {db}.{table_name}")
    holder = str(spark.read.parquet(file).schema)
    fields = holder.split('(')
    for i in fields:
        if ',' in i:
            col = i.split(',')[0:2]
            print('\t'+col[0]+','+col[1])
    print("    ) USING DELTA\n\tLOCATION \"{0}\""+f"\n\t'''.format('{delta_loc}')")